#!/bin/bash
set -eo pipefail
shopt -s nullglob

# Prepare laravel structure
mkdir -p storage/app/public \
    storage/logs \
    storage/framework/cache/data \
    storage/framework/testing \
    storage/framework/views \
    storage/framework/sessions \
    storage/database

# Publish assets in /public directory
php artisan vendor:publish --quiet --all

# Check if database already exist or create a fresh one
if [[ ! -f "/application/storage/database/database.sqlite" ]];
then
    echo "[WARN] SQLite3 database was not found ... Creating ..."
    touch /application/storage/database/database.sqlite
    # Run laravel default migration
    php artisan migrate --force -v
    # Run laravel specific commands
    echo "[INFO] Running Laravel specific commands"
    php artisan hubspot:install
else
    # Update 
    echo "[INFO] SQLite3 database found. "
    echo "[INFO] Running hubspot update ..."
    php artisan hubspot:update
    php artisan migrate --force -v
fi

# Fix ownership
chown www-data:www-data /application -R

# Start webserver
echo "[INFO] Starting webserver ..."

# Run the CMD
exec "$@"
