<?php

namespace Smsto\Hubspot\Http\Controllers\Api;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Http;
use Smsto\Hubspot\Http\Requests\Api\SmstoRequest;
use Smsto\Hubspot\Http\Requests\Api\SendSmstoRequest;
use Smsto\Hubspot\Lib\UrlHelper;
use Smsto\Hubspot\Models\Settings;
use Illuminate\Support\Str;

class SmstoController extends AdminController
{
    /**
     * Get params
     *
     * @author Panayiotis Halouvas <phalouvas@kainotomo.com>
     *
     * @param Smsto\Hubspot\Models\Settings $settings
     * @return \Illuminate\Http\Response|\Illuminate\Contracts\Routing\ResponseFactory
     */
    public function params(Settings $settings)
    {
        $response = [
            "success" => true,
            "message" => null,
            "messages" => null,
            "data" => [
                "show_reports" => $settings->show_reports,
                "show_people" => $settings->show_people
            ]
        ];

        return response($response);
    }

    /**
     * Call smsto
     *
     * @author Panayiotis Halouvas <phalouvas@kainotomo.com>
     *
     * @param Request $request
     * @param Smsto\Hubspot\Models\Settings $settings
     * @return \Illuminate\Http\Response|\Illuminate\Contracts\Routing\ResponseFactory
     */
    public function call(SmstoRequest $request, Settings $settings)
    {
        $validated = $request->validate($request->rules());
        $method = strtolower($validated['_method']);
        $url = $validated['_url'];
        $payload = isset($validated['payload']) ? json_decode($validated['payload'], true) : null;
        $response = Http::withHeaders(['X-Smsto-Integration-Name' => 'hubspot'])->withToken($settings->api_key)->asJson()->acceptJson()->$method($url, $payload);
        return response(json_decode($response, true));
    }

    /**
     * Call smsto
     *
     * @author Panayiotis Halouvas <phalouvas@kainotomo.com>
     *
     * @param Request $request
     * @return \Illuminate\Http\Response|\Illuminate\Contracts\Routing\ResponseFactory
     */
    public function send(SendSmstoRequest $request)
    {
        $validated = $request->validated();

        $settings = Settings::where([
            'app_id' => config('hubspot.app_id'),
            'hub_id' => $validated['origin']['portalId']
        ])->first();

        $validated['inputFields']['sender_id'] = isset($validated['inputFields']['sender_id']) ? $validated['inputFields']['sender_id'] : $settings->sender_id;

        $message = $validated["inputFields"]["message"];
        $detectedLinks = UrlHelper::detectLink($message);
        foreach ($detectedLinks['urls'] as $url) {
            $shorlink_response = Http::acceptJson()->withToken($settings->api_key)->post('https://sms.to/api/v1/shortlink', [
                "name" => 'hubspot_' . $validated['origin']['portalId'],
                "url" => $url,
            ]);
            $shortlink = $shorlink_response->json();
            if (isset($shortlink["success"]) && $shortlink["success"]) {
                $message = Str::replace($url, $shortlink["data"]["fullLink"], $message);
            }
        }
        $validated["inputFields"]["message"] = Str::replace("{{optout}}", "{optout}", $message);

        $api_key = $settings->api_key;
        $response = Http::withHeaders(['X-Smsto-Integration-Name' => 'hubspot'])->withToken($api_key)->asJson()->acceptJson()->post('https://api.sms.to/sms/send', $validated['inputFields']);
        $response = json_decode($response, true);
        if ($response['success']) {
            $settings->createTimelineEvent($validated, 'SUCCESS');
            return response([
                "outputFields" => [
                    'hs_execution_state' => "SUCCESS",
                    "myOutput" => $response['message']
                ]
            ]);
        } else {
            $settings->createTimelineEvent($validated, 'FAILED');
            return response([
                "outputFields" => [
                    'hs_execution_state' => "FAIL_CONTINUE",
                    "myOutput" => "Something went wrong"
                ]
            ]);
        }
    }
}
